package modern;

import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.time.LocalDate;
import java.time.format.DateTimeFormatter;
import java.time.format.DateTimeParseException;

/**
 * CSV出力プログラムのパラメータをまとめたクラスです。
 *
 */
public class Parameter {
    /**
     * ファイルを絞り込む基準となる時刻。
     */
    public final long basetime;
    /**
     * 出力されるCSVのファイルパス。
     */
    public final Path output;
    /**
     * 処理対象のJPEGファイルが格納されたディレクトリ。
     */
    public final Path srcDir;

    public Parameter(String... args) {
        if (args.length != 2 && args.length != 3)
            throw new IllegalArgumentException("第1引数に入力ファイルが格納されたディレクトリのパス、"
                    + "第2引数に出力先となるCSVファイルのパス、"
                    + "第3引数(オプショナル)に基準日を渡さなければいけません");
        srcDir = Paths.get(args[0]);
        if (!Files.isDirectory(srcDir))
            throw new IllegalArgumentException("第1引数はディレクトリでなければいけません");

        output = Paths.get(args[1]);
        if (!output.getFileName().toString().endsWith(".csv"))
            throw new IllegalArgumentException("第2引数の拡張子は.csvでなければいけません");
        if (Files.exists(output))
            throw new IllegalStateException("第2引数で指定するファイルパスは存在しないファイルでなければいけません");

        basetime = (args.length != 3) ? 0L : parse(args[2]).toEpochDay();
    }

    static LocalDate parse(String text) {
        try {
            return LocalDate.parse(text, DateTimeFormatter.ofPattern("yyyyMMdd"));
        } catch (DateTimeParseException e) {
            throw new IllegalArgumentException("第3引数はyyyyMMdd形式の日付でなければいけません", e);
        }
    }
}
