import org.junit.Before;
import org.junit.Ignore;
import org.junit.Rule;
import org.junit.Test;
import org.junit.rules.TemporaryFolder;

import java.io.File;
import java.net.URL;
import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.util.List;

import static org.assertj.core.api.Assertions.assertThat;

/**
 * レガシー版とモダン版の実行結果に差異がない事を確認するためのテスト
 */
public class SmokeAndCompareTest {

    String SRC_DIR;
    String BASETIME = "20160101";

    Path legacyOutput;
    Path modernOutput;

    @Rule
    public TemporaryFolder temp = new TemporaryFolder();

    @Before
    public void setup() throws Exception {
        URL javaLogo = ClassLoader.getSystemResource("java.jpg");
        Path path = Paths.get(javaLogo.toURI()).getParent();
        SRC_DIR = path.toAbsolutePath().toString();

        Path tempRoot = Paths.get(temp.getRoot().toURI());
        legacyOutput = tempRoot.resolve("legacy.csv");
        modernOutput = tempRoot.resolve("modern.csv");
    }

    @Test
    public void smoke_legacy() throws Exception {
        legacy.Main.main(
                SRC_DIR,
                legacyOutput.toString(),
                BASETIME);
    }

    @Test
    public void smoke_modern() throws Exception {
        modern.Main.main(
                SRC_DIR,
                modernOutput.toString(),
                BASETIME);
    }

    @Test
    public void compareTest() throws Exception {
        smoke_legacy();
        smoke_modern();

        List<String> legacy = Files.readAllLines(legacyOutput);
        List<String> modern = Files.readAllLines(modernOutput);
        assertThat(legacy).isEqualTo(modern);
    }
}
